Coverage for /home/tribaal/workspace/django-shop/shop/models/defaults/cart: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/models/defaults/cart : 100.00%

## 8 statements 8 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 | # -*- coding: utf-8 -*- from django.utils.translation import ugettext_lazy as _ from shop.models.defaults.bases import BaseCart class Cart(BaseCart): class Meta(object): abstract = False app_label = 'shop' verbose_name = _('Cart') verbose_name_plural = _('Carts')